#
# spec file for package eza
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           eza
Version:        0.21.3
Release:        1.0.2.1.sr20250501
Summary:        Replacement for ls written in Rust
License:        EUPL-1.2
Group:          System/Base
URL:            https://github.com/eza-community/eza
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
# PATCH-FIX-OPENSUSE smolsheep@opensuse.org -- Fix test in container env gh/eza-community/eza#902
Patch0:         eza-fix-test.patch
BuildRequires:  bash-completion
BuildRequires:  cargo-packaging
BuildRequires:  fish
BuildRequires:  zsh
Provides:       exa = 0.10.1
Obsoletes:      exa <= 0.10.1
%ifnarch %{ix86} %{arm} ppc
BuildRequires:  pandoc
%endif

%description
eza is a modern, maintained replacement for ls, built on exa.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%prep
%autosetup -a1 -p1

%build
%{cargo_build}

%install
%{cargo_install}

# Manpage
# pandoc isnt available everywhere
%ifnarch %{ix86} %{arm} ppc
install -d -m 0755 %{buildroot}%{_mandir}/man1/
pandoc --standalone -f markdown -t man man/eza.1.md > %{buildroot}%{_mandir}/man1/eza.1

install -d -m 0755 %{buildroot}%{_mandir}/man5/
pandoc --standalone -f markdown -t man man/eza_colors.5.md > %{buildroot}%{_mandir}/man5/eza_colors.5
pandoc --standalone -f markdown -t man man/eza_colors-explanation.5.md > %{buildroot}%{_mandir}/man5/eza_colors-explanation.5
%endif

# Completion files
install -Dm0644 completions/bash/eza "%{buildroot}%{_datadir}/bash-completion/completions/%{name}"
install -Dm0644 completions/zsh/_eza "%{buildroot}%{_datadir}/zsh/site-functions/_%{name}"
install -Dm0644 completions/fish/eza.fish "%{buildroot}/%{_datadir}/fish/vendor_completions.d/%{name}.fish"

%check
%{cargo_test}

%files
%license LICENSE.txt
%doc README.md
%{_bindir}/eza
%ifnarch %{ix86} %{arm} ppc
%{_mandir}/man1/eza.1%{?ext_man}
%{_mandir}/man5/eza_colors.5%{?ext_man}
%{_mandir}/man5/eza_colors-explanation.5%{?ext_man}
%endif

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%files zsh-completion
%{_datadir}/zsh/site-functions/_%{name}

%files fish-completion
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%changelog
* Fri May  2 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.22.3:
  * Add support for .ipynb file icons
* Fri Apr 25 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.22.2:
  * Make clippy work again
  * Specify perf improvements
  * Remove dependency on once_cell
  * Add icon for '.stowrc' files
  * Use a hashmap when possible for file extension matching
  * Clean up glob matching code
  * Bump uutils_term_grid from 0.6.0 to 0.7.0
* Tue Apr 22 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.21.1:
  Bug Fixes:
  * Don’t truncate branch name
  * Hi extension icon wasnt working as it was in the wrong aray
  Miscellaneous Tasks:
  * Add MS DOS icon for *.com
  * Add ruby icon for config.ru, Gemfile, Gemfile.lock, procfile,
    rake, rakefile and change ruby icon
  * Add python icon for *.pxd and *.pyx
  * Add markdown icon for *.mdx
  * Add fsharp icon for *.f# and *.fsscript
  * Add clojure icon for *.cljc and *.edn
* Wed Apr  2 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.21.0:
  * Flake bump 2025-03-20
  * Remove unnescesarry unsafe blocks for libc major/minor device id
  * Unwrap -> expect on libc deviceid calls
  * Formatting issue
  * Fix unused PermissionsPlus fields
* Thu Mar 13 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.20.24:
  Bug Fixes:
  * Make temp files visible on white background
  Documentation:
  * More precise temp files color description
  Features:
  * Add .exercism folder icon
  * Add .ocamlinit icon
  * Add .opam folder icon
  Miscellaneous Tasks:
  * Add gcloud icon for .gcloudignore
  * Add vim icon for .gvimrc, _vimrc and _gvimrc
  * Add fennel icon for ~/.fennelrc and ~/.config/fennel/fennelrc
  * Eza v0.20.24 changelogs, version bump
  Build:
  * Bump once_cell from 1.20.3 to 1.21.0
  * Bump terminal_size from 0.4.1 to 0.4.2
  * Bump serde from 1.0.218 to 1.0.219
  * Bump chrono from 0.4.39 to 0.4.40
* Thu Feb 27 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.20.23:
  Bug Fixes:
  * Add Pixi installation instructions
  Build:
  * Bump libc from 0.2.169 to 0.2.170
  * Bump serde from 1.0.217 to 1.0.218
  * Bump log from 0.4.25 to 0.4.26
  * Bump trycmd from 0.15.8 to 0.15.9
* Fri Feb 21 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.20.22:
  Features:
  * Add prettier icon for *.prettierignore
  * Add icon for *.hrl
  * Add photoshop icon for *.psb
  * Add eslint icon for .eslintignore
  * Add renovate icon for renovate.json
  * Add elixir icon for *.eex, *.leex and mix.lock
  Build:
  * Bump once_cell from 1.20.2 to 1.20.3
* Fri Feb 14 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.20.21:
  * Start publishing libgit arm builds
* Fri Feb  7 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.20.20:
  Bug Fixes:
  * Make flake.lock icon the nix logo
* Thu Jan 30 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.20.19:
  Bug Fixes:
  * Update MSRV to 1.78 to solve rust malfunction
  * Rustc false dead code positives
  * Rustc false positives in tests
  * Regression in theme config location, simplify path
  * Wrong file name for Brewfile
  Documentation:
  * Add note regarding ci msrv update
  Features:
  * Add .norg icon
  Build:
  * Bump dirs from 5.0.1 to 6.0.0
  * Bump NexusPHP/no-merge-commits from 2.1.0 to 2.2.1
  * Bump flake
  * Bump cargo
  Ci:
  * Fix and unify msrv and add matrix to free/netbsd
* Tue Jan 28 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.20.18:
  Bug Fixes:
  * Support additional yaml file extension, clippy
  Build:
  * Cargo bump 2025-01-23
  * Flake bump 2025-01-23
* Fri Jan 17 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.20.17:
  Features:
  * Add editorconfig icon for .editorconfig
  Build:
  * Cargo bump 2025-01-16
  * Flake bump 2025-01-16
* Thu Jan  9 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.20.16:
  * Add brew icon for brewfile and brewfile.lock.json
  * Update flake inputs 2025-01-08
  * Update cargo inputs 2025-01-08
  * Bump git2 from 0.19.0 to 0.20.0
* Thu Jan  2 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.20.15:
  * Add icons from nerd fonts 3.3.0 release & more
  * Add new icons, extensive list
  * We switch to our own fork of natord
* Fri Dec 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.14:
  Bug Fixes:
  * ...those pesky workflow targets
  * Remove separate bsd tests
  * Remove audit workflow
  Features:
  * Audit checks in main CI
  Styling:
  * Format workflows
  * Ci checks formatted
* Fri Dec 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.13:
  Bug Fixes:
  * Pre-commit-hooks.nix trying to be too clever
  * Remove stray description (originally from --decay-mode)
  Build:
  * Update crate deps Mon Dec 16
  * Update flake deps Mon Dec 16
* Mon Dec 16 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.12:
  Bug Fixes:
  * Add unicode-3.0 license
  * Use safe terminal_size_of
  * Use terminal_size_of with borrowed raw handle
  Features:
  * Move MSRV to 1.74 and deep bump cargo deps
  * Add Gleam lang icon
* Mon Dec 16 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.11:
  Bug Fixes:
  * Bump libc from 0.2.165 to 0.2.167
* Tue Nov 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.9:
  Bug Fixes:
  * Remove newline after doc comment of regen recipe
  Refactor:
  * List all recipes by default
  * Group related recipes
* Tue Nov 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.8:
  Bug Fixes:
  * Cross-compiling by updating to libz-sys to 1.1.20
* Tue Nov 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.7:
  Bug Fixes:
  * Palette v0.7.6 -> v0.7.5
* Tue Nov 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.6:
  * Fix typo --get-repos-no-status to --git-repos-no-status
* Fri Oct 25 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.5:
  Bug Fixes:
  * Ensure nested tree parts align under item name
  * Remove depricated chrono from_timestamp_opt
  Build:
  * Bump libc from 0.2.159 to 0.2.161
  * Chrono v0.4.34 -> v0.4.38
- Update eza-fix-test.patch
* Sat Oct 19 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.4:
  * Filetype, coloring for executables and folder
* Thu Oct 17 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.3:
  * Fix Git cliff docs issue
  * Reuse filetype from DirEntry resulting in a
    approximately ~24%% speedup for most common operations.
* Wed Oct 16 2024 Michael Vetter <mvetter@suse.com>
- Update eza-fix-test.patch to fix tests
* Wed Oct  9 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.2:
  Bug Fixes:
  * Colors in old ms command prompt
  * Bring help text in line with available flags
  * Do not print parent filename with --absolute=on
  Miscellaneous Tasks:
  * Add fox installation option
* Fri Oct  4 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.1:
  Bug Fixes:
  * Release recipe
  * Support passing multiple options for generate-trycmd-test.sh
  * Move options into flags
  * Rustfmt errors
  Documentation:
  * Fix cross-references
  * Update file type colors
  * Document that exit 13 == permission denied
  Features:
  * Update just, add more formats
  * Recursively walk symlinks pointing at dirs
  * Add --follow-symlinks option
  * Add autocomplete for --follow-symlinks
  * Show directories last
  Testing:
  * Add cases for -T and --follow-symlinks
  * Regenerate tests broken by line number changes
* Thu Sep 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.0:
  Bug Fixes:
  * Flake trycmd bug
  * Pre-commit-hook taplo bug
  Documentation:
  * Add link to eza-themes repository in readme
  * Cargo install dir inaccurate
  * Add x-cmd method to install eza
  * Adding a testing infos file to guide everyone through tests
  Features:
  * Add opml file extension
  * Add a regen rule
  * [breaking] Relicensed to EUPL-1.2
  Refactor:
  * Move some files to .config
  * Release scripts use .config
  * Relicense to EUPL-1.2
* Wed Sep 18 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.19.4:
  Bug Fixes:
  * Remove non_alpha from percent encoding to fix hyprlinks
  Features:
  * Pass from serde_yaml to serde_norway
* Thu Sep 12 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.19.3:
  Bug Fixes:
  * Convert empty space to %%20 when render hyperlinks
  * Split commit workflows and run no-merge-commits only on PRs
  * Correct naming of commit related workflows
  Documentation:
  * Better version bump commit summary
  Features:
  * Add no-merge-commits job to commits workflow
* Thu Sep  5 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.19.2:
  Bug Fixes:
  * Remove unnecessary map and make clippy happy
  * Adjust grid details for CI tests
  * Imports and merge conflicts
  * Rustfmt issues
  * Clippy issues
  * Revise UiStyles::plain to have no style at all
  * Pr reviews fixes for theme file
  * Selectively filter files when recursing #1101[3]
  * Fix typo in FromOverride impl
  * Add serde(default) to StyleOverride.foreground/background fields
  Documentation:
  * Add Flox to INSTALL.md
  * Add ic for icon color to colors man page
  * Add further documentation about theme file
  Features:
  * Add c++ module interfaces as source file types
  * Add icon field to UiStyles
  * Add ic key for UiStyles icon in set_exa
  * Add None as icon value in UiStyles.default_theme
  * Add icon function to FileNameColours trait
  * Implement FileNameColours.icon for Theme
  * Adjust FileName.paint to consider possible icon color
  * Begin implementation of config file
  * Allow writing default theme.yml file for eventual config file implementation
  * Theme file configuration base
  * Add IconOverrides struct and UiStyles.icon_overrides
  * Add icon_override function to FileNameColours trait
  * Implement FileNameColours.icon_override for Theme
  * Handle icon overrides in FileName.paint
  * Add example config for icon_overrides
  * Rename UiStyles.icon_override to icons and add Style field
  * Add shorthand aliases to StyleOverride variables
  * Add custom deserialize_color and use in StyleOverride
  * Outsource color_from_str function to make it testable
  Refactor:
  * Simplify icon style setting in FileName.paint
  * Make every setting optional with override layer
  * Simplify sample theme.yml
  * Formatting for rustfmt macro
  Styling:
  * Fix clippy issue in FileName.paint
  * Apply rustfmt
  * Simplify from_str_radix calls to please clippy
* Mon Sep  2 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.19.1:
  * FreeBSD build
  * Typo
  * Bump uzers from 0.12.0 to 0.12.1
* Thu Aug  8 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.19.0:
  * [breaking] Implement EZA_GRID_ROWS grid details view minimum rows threshold
    Before this change, the EZA_GRID_ROWS variable was
    ignored, despite documentation existing. Users relying on EZA_GRID_ROW
    not doing anything will find their output changed. For more info, see
* Mon Aug  5 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.24:
  * Fix 1.80 breakage from time crate
* Thu Jul 25 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.23:
  Bug Fixes:
  * Disable broken freebsd tests
  Documentation:
  * Clear up confusion around ls
  Build:
  * Bump log from 0.4.21 to 0.4.22
  * Bump DeterminateSystems/nix-installer-action from 12 to 13
  * Bump plist from 1.6.1 to 1.7.0
* Thu Jul 18 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.22:
  * Use NaiveDateTime::from_timestamp_opt instead of panicky From impl
  * Add non-nix pre-commit rustfmt and clippy hooks
* Mon Jul  1 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.21:
  * Fix missing line breaks in _eza
* Thu Jun 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.20:
  * Add --no-|show-symlinks flags for filtering output
* Thu Jun 20 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.19:
  Bug Fixes:
  * Ship release binaries
  Build:
  * Bump git2 from 0.18.3 to 0.19.0
* Fri Jun 14 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.18:
  * Extend deny check in audit workflow to all
  * Add deny.toml and workflow file to audit workflow paths
  * Run on all features by default
  * Ask for shell and terminal in bug report template
* Thu Jun  6 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.17:
  * Add icon for Nushell extension
  * Bump trycmd from 0.15.1 to 0.15.2
  * Bump libc from 0.2.154 to 0.2.155
- Disable cargo vendor filterer for now:
  Seems to have a problem with true/false right now
* Fri May 17 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.16:
  * Change windows-only imports to be windows-only
  * Replace decay with color-scale
  * Update INSTALL.md
  * Fix typo in INSTALL.md
  * Use 3 columns for packaging status badge
* Mon May 13 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.15:
  * Correct command for latest tag in deb-package.sh
  * Add how to find man pages in terminal and online. Partly fixes #967
  * Correct heading levels in markdown
  * Move heading out of collapsed section
  * Add some keywords for benefit of ctrl-f
  * Return to original commit at the end of deb-package.sh
  * Add optional tag argument to deb-package.sh
* Thu May  2 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.14:
  * Add icon for "cron.minutely" directory
  * Bump uzers from 0.11.3 to 0.12.0
  * Bump libc from 0.2.153 to 0.2.154
  * Bump unicode-width from 0.1.11 to 0.1.12
  * Bump palette from 0.7.5 to 0.7.6
* Thu Apr 25 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.13:
  * Generate completion/manpage tarballs on release
* Fri Apr 19 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.11:
  * Fix clippy lints
  * Enable the rule only for NetBSD.
  * Build aarch64, arm without libgit2
* Thu Apr 11 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.10:
  Bug Fixes:
  * Bump trycmd from 0.15.0 to 0.15.1
* Wed Mar 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.9:
  * Switch out ansiterm crate for nu_ansi_term
  * Bump DeterminateSystems/nix-installer-action from 9 to 10
  * Bump plist from 1.6.0 to 1.6.1
  * Bump rayon from 1.9.0 to 1.10.0
  * Bump git2 from 0.18.2 to 0.18.3
* Thu Mar 21 2024 Michael Vetter <mvetter@suse.com>
- Filter dependencies for vendor tarball
- Cleanup changes and comments from last submission
* Thu Mar 21 2024 Joshua Smith <smolsheep@opensuse.org>
- Add eza-fix-test.patch:
  Fix test in container build environment.
  See gh/eza-community/eza#902
- Remove unneeded cargo_config
- Update to 0.18.8:
  Bug Fixes:
  * Avoid deprecation warnings
  * Rustfmt issues
  Features:
  * Add fennel lang icon and associations
* Wed Mar 20 2024 Michael Vetter <mvetter@suse.com>
- Filter dependencies for vendor tarball
* Thu Mar 14 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.7:
  * Bugfix to resolve absolute paths that are not symlinks
  * Add filetype and icon for .hh extension
* Wed Mar  6 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.6:
  Bug Fixes:
  * NetBSD did not have fflagstostr and as such did not build properly
  * Fix total-size option
  * Add fortran to source filetypes
  * Fix absolute_path() for broken symlinks
  * Update line numbers in panic messages in tests
  Features:
  * Add filetype and icon for age
  * Adding icons for graphql extensions
  * Add nim icons
  * Use fsharp icon for fsproj files (similar to cs/csproj)
  * Add new icons, diverse selection
  * Adding more haskell related icons
  * Adding more icons for docker specific files
  * Adding more dockerfile icons
  * Add --absolute flag
  * Add shell completions for --absolute flag
* Thu Feb 29 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.5:
  Bug Fixes:
  * Bump palette from 0.7.4 to 0.7.5
* Thu Feb 22 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.4:
  Bug Fixes:
  * Classification width should be taken into account with -F=auto
  Build:
  * Bump libc from 0.2.152 to 0.2.153
  * Bump chrono from 0.4.33 to 0.4.34
  * Bump trycmd from 0.14.20 to 0.15.0
* Thu Feb 15 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.3:
  * Duplicates in shell completions
  * Add target arch to deb PPA installation for strict apt environments
  * Do not pre-compute MountInfo to reduce readlink calls
  * Use #[default] attribute instead of custom impl for enums
* Thu Feb  8 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.2:
  * This security release fixes GHSA-3qx3-6hxr-j2ch (bsc#1221053)
  * Update libgit2 to 1.7.2
* Thu Feb  8 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.1:
  * Add manual installation section
  * Replace scoped_threadpool with rayon
* Thu Feb  1 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.0:
  * [breaking] Add --classify=always,auto,never
  * Remove rustfmt config file that has a nightly only option in
    favor of rustfmt skip directive which is already in place
  * Fix small typo in pull request template
  * Change cast to coertion, remove rustfmt skip and clippy lint
    ignore directives
  * Regenerate classification related tests
* Thu Jan 25 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.17.3:
  * Remove version testing
  * Avoid unwrap() by changing filter-then-map to filter_map
* Sun Jan 21 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.17.2:
  Bug Fixes:
  * Crash using --git-repos on unreadable dir
  * Crash using --git-repos on unreadable dir
* Fri Jan 12 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.17.1:
  Bug Fixes:
  * Offset widths in grid mode with utf8 filenames
  * Format the code
  * Unformat the code where needed
  * Format the code correctly this time
  * Redo everything from scratch
  * Stack overflow when '-laaR' are used
  * Stack overflow when '-laaR' is used
  Features:
  * Add Fortran icons
* Wed Dec 13 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  Breaking changes:
  * Extend the +<FORMAT> custom time style, accept an optional
    ...<newline><FORMAT_2> to support setting a different custom time
    style for recent files.
    The behavior changes if the previous format string
    already contains <newline>. Previously <newline>s are used as-is,
    now the first newline will be interpreted as separation for non-recent
    and recnet format; any content after the second newline, if any, are
    simply ignored.
    The implementation rejects some previously accepted
    inputs, primarily empty non-recent format string. --time-style=+
    and --time-style='+<newline>' will now get a panic message.
  Bug Fixes:
  * Add color scale mode to the bash completions
  * Add color scale mode to the fish completions
  * Quote symbolic links correctly when their destinations contain spaces
  Documentation:
  * Modify documentation about custom time style
  Features:
  * Add BSD file flags
  * Add Windows file attributes
  * [breaking] Support different custom time style for non-recent/recent files
* Thu Dec  7 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.16.3:
  * Add bare git_repos fn if feature git is disabled
  * Fixing color of size unit
  * Color-scale broked size for colors
* Fri Dec  1 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.16.2:
  * Calculate width correctly when using grid icons & classify
  * Fix the windows build
* Thu Nov 23 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.16.1:
  Bug Fixes:
  * Don't panic with todo!() on inaccessible dir
  * Don't panic if the btime of a file is Err
  * Lifetime annotations and manpage/shell completion nits
  * Reflow help
  Features:
  * Handle formatting and display of binary extended attributes.
  * Add netbsd and freebsd support for extended attributes
* Thu Nov 16 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  Bug Fixes:
  * [breaking] Remove Repo column when using --git-repos when no git repo
  * Fix cross compilation
  * Snap requires a base
  * Move --smart-group to long view options
  * Colo[u]r-scale didn't have a base value
  * Fix snapcraft.yaml formatting
  Documentation:
  * Add comments for bzip variants
  * Added the fact that total-size is unix only
  Features:
  * Add some file extensions
  * Abort on panic (saving 0.1 M)
  * Add powertest
- Switch from ~ to + in version
* Fri Nov 10 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.15.3:
  Bug Fixes:
  * Changed quote in --almost-all completion
  * Reformat help.rs
  * Allow unused macro rule arms
  Documentation:
  * Improve CONTRIBUTING.md, README.md
  * Improve README.md
  * Introduce INSTALL.md
  Features:
  * Create EZA_ICONS_AUTO environment variable
  * Create EZA_ICONS_AUTO environment variable
  * Demo gif and gif generation recipe
  * Add ocaml icon filetypes
  * Add PRQL
  * Add --color-scale
* Thu Nov  2 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.15.2:
  * Correct width when --no-quotes is used
  * Clippy lint and add option to grid-details
  * --smart-group only worked for current user
  * Add Typst to the recognized files
* Thu Oct 26 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.15.1:
  * Fmt, windows, and nix fixes
  * Reverted autofmt changes
  * Don’t display target’s size if we’re not dereferencing
  * Updated match indents
  * Changed flag name
  * Only store top-level recursive dir size
  * Changed windows methods
  * Underscored unused windows variables
  * Added device for filesystem to hashmap
  * Display offset for filenames with spaces
  * Fix clippy warnings
  * Fix doc-tests on RecursiveSize
  * Fix dead_code warnings on Windows
  * Added flag to readme
  * Added flag to man
  * Fix doc-tests formatting and address other documentation review requests
  * Added recursive directory parser
  * Added flag to completions
  * Add a new filetype for source code files
  * Add a new icons for source code files and other files
  * Support for displaying blocksize on directories
- Drop fix-offset-for-filenames-with-spaces.patch
* Wed Oct 25 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Add fix-offset-for-filenames-with-spaces.patch. Fixes ugly offset
* Thu Oct 19 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.15.0:
  * Reenable debug symbols in debug builds
  * Clippy lint
  * Merge conflict with main
  * Correct color option spellings
  * Add option --smart-group
  * Add completions, man for --smart-group
  * Add icons=always,auto,never. dont display icons in a tty|piped
  * Fix auto value for colors and icons + documentation
  * [breaking] Remove --no-icons in favor of --icons=always,auto,never
    default is auto
* Fri Oct 13 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.14.2:
  * Comment out redundant static musl build
  * Refactor sed command to build manpages
  * Update additional completions for help, almost-all, dereference
  * Fix zsh completions
  * Add missing options to man page and CLI --help info
  * Add missing nu shell completions
  * Adding the EZA_OVERRIDE_GIT env var
* Sun Oct  8 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.14.1:
  * Replace left-over exa in fish completion
  * Diabling static linked binaries due to segfault
  * Make os error 13 fail loud
  * Adjust change width calculations for hyperlink and classify
  * Root group not painted as expected when eza used by root
  * Add basic nushell completion file
* Mon Oct  2 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.14.0:
  * BREAKING CHANGES:
    + "un" does no longer set color for root user use "uR" instead
    + "gn" does no longer set color for root group use "gR" instead
    + This is a change in behaviour from before, and so we
    have marked it as breaking. In practice, it probably won't break
    anything except if you're doing something really weird.
  * We now have --time-style, for date like time formatting
  * Add quotations around filenames with spaces. exa pr#1165
  * Added statically linked binaries
  * Add header to colors-explanation page
  * Some new icons
* Mon Sep 25 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.13.1:
  Bug Fixes:
  * Typo this -> that
  * Error for missed semicolon
  * More than 3 bools in a struct
  * Major and minor device on MacOS
  * Linux uses u32 for major/minor device numbers
  * Respect spec on Windows and make it for with Konsole
  * Don’t show color when color is disabled
  * Enable rustfmt by removing .rustfmt.toml which disables it
  * Replace rustfmt::skip on expressions because experimental
  * Remove unnecessary rustfmt::skip's in windows code
  * Add src/options/flags.rs to rustfmt.excludes
  * Left-over merge conflict in src/output/table
  Documentation:
  * Update README.md
  * Update --mounts option to include MacOS
  * Documenting --only-files
  Features:
  * Listing files only using '--only-files' flag
    Add EXA_COLOR bindings for un-themed items
  * Add EZA_ environment variables with fallback to EXA_
  * Add rustfmt check to unit-tests workflow
  Miscellaneous Tasks:
  * Add completion for --only-fies (zsh,fish)
* Mon Sep 18 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.13.0:
  Features:
  * Add completion files in deb packaging script
  * Adds filtering for Windows hidden files
  * Support --mount option on Mac
  * Lazy loading of a files extended attributes and absolute path
  Bug Fixes:
  * Crate can't contain broken symlink
  * Remove executable flag from fish completion file
  * Use proc_mounts only on linux
  * Hotfix harmful documentation
  * Fix hyperlinks on Windows
  * Nix flake check also builds the package
  * [breaking] Change number_huge and unit_huge to match the man page short codes
* Fri Sep 15 2023 Michael Vetter <mvetter@suse.com>
- Add version to provides/obsoletes
* Fri Sep 15 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.12.0:
  Bug Fixes:
  * Expand --all help
  * RUSTSEC-2020-0071
  * Generalize gitignore to ignore all eza deb packages
  * Canonicalize errors when the destination of a symbolic link is bad
  * Handle other canonicalize errors in hyperlinks and git
  * Fix windows build when canonicalize returns an error
  * Change trycmd config to use test/itest folder for testing
  * Revert to old apt install command suggestion and add hint
  * Remove stray backslashes
  * Is_some_and is an unstable Rust feature until 1.70
  * Revert "Support for Windows Hidden Files"
  * Shellcheck warnings
  * Revert "Support for Windows Hidden Files"
  * Shellcheck warnings
  * Exit 13 on os error 13
  * Rewrite comment
  * Improve trace strings
  * Tracing typo
  Documentation:
  * Expand --all documentation
  * Add pthorpe92 gist
  * Remove xtests section from readme
  * Add deprecation warning to xtests/readme
  * Add deprecation warning to just xtest commands
  * Add deprecation warning to vagrantfile
  * Add MacPorts install info
  * Add gentoo
  * Fix gentoo install
  * Add docs for --git-repos & --git-repos-no-status
  * Fix gpg armor flag for deb release in readme
  * Add better explanation of git repos + no status
  * Add scoop install info
  * Remove color specifications. change unknown git repo status to ~
  * Fix missing color specification from man page
  Features
  * Add audit workflow
  * Add trycmd as dev-dependency
  * Add minimal trycmd binary
  * Add a few trycmd tests as example
  * Document and change output for --git-repos
  * Add apt installation workflow
  * Adds filtering on Windows hidden files
  * Adds filtering on Windows hidden files
  * Adds filtering on Windows hidden files
  * Added shellcheck to treefmt
  * Adds filtering on Windows hidden files
  * Add PERMISSION_DENIED exit code
* Mon Sep 11 2023 Michael Vetter <mvetter@suse.com>
- Add Provides/Obsoletes exa
  Since exa seems not maintained and eza wants to continue
  its work
* Mon Sep 11 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.11.1:
  Bug Fixes:
  * Add vendored-libgit2 feature to git2 dependency
  * Filename escaping (last character lost sometimes, no hyperlink)
  * Build for Windows with chrono
  Documentation:
  * Explain vendored-libgit2
  * Add homebrew, misc fixes
  * Fix code of conduct link
  * Update archlinux
  * Add star history
  * Add informaton about lazy_static
  * Remove broken dependabot link
  * Add bright color options in man pages
  * Add bright color support in readme changelog
  Features:
  * Add highlighting of mounted directories (Linux only)
  * Add backlog of icons from various exa pull requests and others
  * Mark .git as ignored, which hides it when using --git-ignore
  * Add backlog of icons from various exa issues
  * Expose git2 feature vendored-libgit2
  * Add build commands to deb-package.sh
  * Support the MSRV of Rust (1.65.0)
  * Add bright colour options, change punctuation default
  * Use chrono crate to handle datetime-related features
* Thu Sep  7 2023 Michael Vetter <mvetter@suse.com>
- Initial package for eza 0.11.0 for openSUSE
